@@ -21,7 +21,9 @@ pub use crate::{
 };
 
 pub mod config;
+pub mod dumping;
 pub mod errors;
+pub mod group;
 pub mod messages;
 pub mod node;
 pub mod routers;
@@ -39,10 +41,8 @@ mod addr;
 mod address_book;
 mod context;
 mod demux;
-mod dumping;
 mod envelope;
 mod exec;
-mod group;
 mod local;
 mod macros;
 mod mailbox;
@@ -59,9 +59,13 @@ pub mod _priv {
         pub use crate::dumping::*;
 
         #[inline]
-        pub fn of<C, K, S>(context: &crate::Context<C, K, S>) -> &Dumper {
+        pub fn of<C: 'static, K, S>(context: &crate::Context<C, K, S>) -> &Dumper {
             context.dumper()
         }
+
+        pub fn set_in_dumping(flag: bool) {
+            crate::dumping::set_in_dumping(flag);
+        }
     }
 
     pub mod node {
